# AttachmentFieldIdOrNameUploadAttachmentBody

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**content_type** | **str** | Content type, e.g. \&quot;image/jpeg\&quot; | 
**file** | **str** | The base64 encoded string of the file to be uploaded | 
**filename** | **str** | Filename, e.g. \&quot;foo.jpg\&quot; | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

